--
-- PowerShaftAttacher
-- Specialization for PowerShaftAttacher
--
-- @author  Manuel Leithner
-- @date  26/07/09
--

PowerShaftAttacher = {};

function PowerShaftAttacher.prerequisitesPresent(specializations)
    return true;
end;

function PowerShaftAttacher:load(xmlFile)
    --BunkersiloCompactor--
    self.bunkerSiloCompactingScale = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.bunkerSiloCompacter#compactingScale"), 1);
    self.bunkerSiloCompactingRefNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.bunkerSiloCompacter#refNode"));
	--WheelParticle--
	self.wheelParticleSystems = {};
    local psFile = getXMLString(xmlFile, "vehicle.wheelParticleSystems#file");
    if psFile ~= nil then
        local i=0;
        while true do
            local baseName = string.format("vehicle.wheelParticleSystems.wheelParticleSystem(%d)", i);
            local node = getXMLString(xmlFile, baseName.. "#node");
            if node == nil then
                break;
            end;
            node = Utils.indexToObject(self.components, node);
			self.wheelParticleSystems.node = node;
            if node ~= nil then
                local wheelParticleSystem = {};
                wheelParticleSystem.particleSystems = {};
                Utils.loadParticleSystem(xmlFile, wheelParticleSystem.particleSystems, "vehicle.wheelParticleSystems", node, false, nil, self.baseDirectory);
                table.insert(self.wheelParticleSystems, wheelParticleSystem);
            end;
            i = i+1;
        end;
    end;
	--PowershaftAttacher--
	local i=0;
    while true do
        local baseName = string.format("vehicle.attacherJoints.attacherJoint(%d)", i);
        local index = getXMLString(xmlFile, baseName.. "#index");
        if index == nil then
            break;
        end;		
		local joint = self.attacherJoints[i+1];
		local shaftAttacher = Utils.indexToObject(self.components, getXMLString(xmlFile, baseName .. "#shaft"));
		if shaftAttacher ~= nil then
			joint.powerShaftAttacher = shaftAttacher;
		end;
		
		i = i + 1;
	end;
    
	local attacherJointCount = i;
	i = 0;
    while true do
        local baseName = string.format("vehicle.trailerAttacherJoints.trailerAttacherJoint(%d)", i);
        local index = getXMLString(xmlFile, baseName.. "#index");
        if index == nil then
            break;
        end;
		
		local joint = self.attacherJoints[attacherJointCount + 1 + i];
		local shaftAttacher = Utils.indexToObject(self.components, getXMLString(xmlFile, baseName .. "#shaft"));
		if shaftAttacher ~= nil then
			joint.powerShaftAttacher = shaftAttacher;
		end;
        i = i+1;
    end;	
	self.showHelp = false;
end;

function PowerShaftAttacher:delete()
    --WheelParticle--
	for i=1, table.getn(self.wheelParticleSystems) do
		Utils.deleteParticleSystem(self.wheelParticleSystems[i].particleSystems);
    end;
end;

function PowerShaftAttacher:readStream(streamId, connection)
end;

function PowerShaftAttacher:writeStream(streamId, connection)
end;

function PowerShaftAttacher:mouseEvent(posX, posY, isDown, isUp, button)
end;

function PowerShaftAttacher:keyEvent(unicode, sym, modifier, isDown)
end;

function PowerShaftAttacher:update(dt)
    --Show Help--
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.TOGGLE_SHOW_HELP) then
			self.showHelp = not self.showHelp;
		end;
	end;
	--WheelParticle--
	local dens = 0; local dens1; local dens2; local dens3; local dens4;
	local x,y,z = getWorldTranslation(self.wheels[2].repr);
	local x1,y1,z1 = getWorldTranslation(self.wheels[1].repr);
	local x2,y2,z2 = getWorldTranslation(self.wheels[4].repr);
	local id = g_currentMission.terrainDetailId;
	local xx, zz, widthX, widthZ, heightX, heightZ = Utils.getXZWidthAndHeight(id, x, z, x1, z1, x2, z2);
	dens1 = getDensityParallelogram(id, xx, zz, widthX, widthZ, heightX, heightZ, g_currentMission.cultivatorChannel, 1);
	dens2 = getDensityParallelogram(id, xx, zz, widthX, widthZ, heightX, heightZ, g_currentMission.sowingChannel, 1);
	dens3 = getDensityParallelogram(id, xx, zz, widthX, widthZ, heightX, heightZ, g_currentMission.ploughChannel, 1);
	dens4 = getDensityParallelogram(id, xx, zz, widthX, widthZ, heightX, heightZ, g_currentMission.sprayChannel, 0);
	if g_currentMission.environment.lastRainScale <= 0.1 and g_currentMission.environment.timeSinceLastRain > 30 then
		dens = dens1+dens2+dens3+dens4;
	end;
	if dens > 0 and self.lastSpeed*self.speedDisplayScale*3600 > 4 then
		for i=1, table.getn(self.wheelParticleSystems) do
			Utils.setEmittingState(self.wheelParticleSystems[i].particleSystems, self.wheels[i].hasGroundContact);
		end;
	else
		for i=1, table.getn(self.wheelParticleSystems) do
			Utils.setEmittingState(self.wheelParticleSystems[i].particleSystems, false);
		end;
	end;
end;

function PowerShaftAttacher:updateTick(dt)
end;

function PowerShaftAttacher:draw()
	if not self.showHelp then
--		renderText(0.757, 0.22, 0.018, "Numpad 0:");
--		renderText(0.865, 0.22, 0.018, "Info einblenden");
		g_currentMission:addHelpButtonText(g_i18n:getText("ShowHelp1"), InputBinding.HUDINFO);
	 else
		renderText(0.757, 0.22, 0.018, "Numpad Enter:");
		renderText(0.865, 0.22, 0.018, "Motor starten/stopen");
		renderText(0.757, 0.235, 0.018, "Numpad 1:");
		renderText(0.865, 0.235, 0.018, "Blinker Links");
		renderText(0.757, 0.25, 0.018, "Numpad 2:");
		renderText(0.865, 0.25, 0.018, "Warnblinker");
		renderText(0.757, 0.265, 0.018, "Numpad 3:");
		renderText(0.865, 0.265, 0.018, "Blinker Rechts");
		renderText(0.757, 0.28, 0.018, "Numpad 5:");
		renderText(0.865, 0.28, 0.018, "Arbeitslicht vorn");
		renderText(0.757, 0.295, 0.018, "Numpad 6:");
		renderText(0.865, 0.295, 0.018, "Zusatzlicht hinten");
		renderText(0.757, 0.31, 0.018, "F:");
		renderText(0.865, 0.31, 0.018, "Abblendlicht");
		renderText(0.757, 0.325, 0.018, "F halten:");
		renderText(0.865, 0.325, 0.018, "Fernlicht");
		renderText(0.757, 0.34, 0.018, "Pos1:");
		renderText(0.865, 0.34, 0.018, "Rundumleuchte");
		renderText(0.757, 0.355, 0.018, "0:");
		renderText(0.865, 0.355, 0.018, "Hupe");
		renderText(0.757, 0.37, 0.018, "Pos1:");
		renderText(0.865, 0.37, 0.018, "Rundumleuchte");
		renderText(0.757, 0.385, 0.018, "Bild runter:");
		renderText(0.865, 0.385, 0.018, "RPM -");
		renderText(0.757, 0.40, 0.018, "Bild rauf:");
		renderText(0.865, 0.40, 0.018, "RPM +");
		renderText(0.757, 0.415, 0.018, "Spacetaste:");
		renderText(0.865, 0.415, 0.018, "Interactiv Control");
		renderText(0.757, 0.43, 0.018, "Taste 5:");
		renderText(0.865, 0.43, 0.018, "Heckscheibe");		
		renderText(0.757, 0.445, 0.018, "Taste 6:");
		renderText(0.865, 0.445, 0.018, "Frontscheibe");
		renderText(0.757, 0.46, 0.018, "Taste 8:");
		renderText(0.865, 0.46, 0.018, "Fahrertuer");

		g_currentMission:addHelpButtonText(g_i18n:getText("ShowHelp2"), InputBinding.HUDINFO);
	end;
end;

function PowerShaftAttacher:onDetach()
	self.oldAttacherJoint.steeringAxleNode = self.oldSteeringAxleNode;
end;

function PowerShaftAttacher:onAttach(attacherJoint)
	self.oldAttacherJoint = attacherJoint;
	self.oldSteeringAxleNode = attacherVehicle.steeringAxleNode;
	attacherJoint.steeringAxleNode = self.components[1].node
end;

function PowerShaftAttacher:onLeave()
    --Show Help--
	self.showHelp = false;
end;